@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Indicates batch convert file request',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'BatchConvertRequest',
                                   required => [], # TODO
 }                                 );
@@ -129,56 +129,49 @@ __PACKAGE__->method_documentation({
      'source_folder' => {
      	datatype => 'string',
      	base_name => 'SourceFolder',
-     	description => 'The directory stores files that need to format conversion.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'source_storage' => {
      	datatype => 'string',
      	base_name => 'SourceStorage',
-     	description => 'Aspose Cloud storage name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'match_condition' => {
      	datatype => 'MatchConditionRequest',
      	base_name => 'MatchCondition',
-     	description => 'Indicates the match condition that needs to be processed for the file name.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'format' => {
      	datatype => 'string',
      	base_name => 'Format',
-     	description => 'Conversion format.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'out_folder' => {
      	datatype => 'string',
      	base_name => 'OutFolder',
-     	description => 'The directory that stores files whose format conversion was successful.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'out_storage' => {
      	datatype => 'string',
      	base_name => 'OutStorage',
-     	description => 'Aspose Cloud storage name.',
-     	format => '',
-     	read_only => '',
-     		},
-     'region' => {
-     	datatype => 'string',
-     	base_name => 'Region',
-     	description => 'The regional settings for workbook.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'save_options' => {
      	datatype => 'SaveOptions',
      	base_name => 'SaveOptions',
-     	description => 'Indicates save options.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
@@ -191,7 +184,6 @@ __PACKAGE__->swagger_types( {
     'format' => 'string',
     'out_folder' => 'string',
     'out_storage' => 'string',
-    'region' => 'string',
     'save_options' => 'SaveOptions' 
 } );
 
@@ -202,7 +194,6 @@ __PACKAGE__->attribute_map( {
     'format' => 'Format',
     'out_folder' => 'OutFolder',
     'out_storage' => 'OutStorage',
-    'region' => 'Region',
     'save_options' => 'SaveOptions' 
 } );
 
