@@ -131,91 +131,91 @@ __PACKAGE__->method_documentation({
      'area' => {
      	datatype => 'Area',
      	base_name => 'Area',
-     	description => 'Gets the area. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'auto_scale_font' => {
      	datatype => 'boolean',
      	base_name => 'AutoScaleFont',
-     	description => 'True if the text in the object changes font size when the object size changes. The default value is True. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'background_mode' => {
      	datatype => 'string',
      	base_name => 'BackgroundMode',
-     	description => 'Gets and sets the display mode of the background ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'border' => {
      	datatype => 'Line',
      	base_name => 'Border',
-     	description => 'Gets the border. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'font' => {
      	datatype => 'Font',
      	base_name => 'Font',
-     	description => 'Gets a  object of the specified ChartFrame object. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_automatic_size' => {
      	datatype => 'boolean',
      	base_name => 'IsAutomaticSize',
-     	description => 'Indicates whether the chart frame is automatic sized. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_inner_mode' => {
      	datatype => 'boolean',
      	base_name => 'IsInnerMode',
-     	description => 'Indicates whether the size of the plot area size includes the tick marks, and the axis labels.            False specifies that the size shall determine the size of the plot area, the tick marks, and the axis labels. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => 'True if the frame has a shadow. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'shape_properties' => {
      	datatype => 'ARRAY[LinkElement]',
      	base_name => 'ShapeProperties',
-     	description => 'Gets the  object. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'width' => {
      	datatype => 'int',
      	base_name => 'Width',
-     	description => 'Gets or sets the width of frame in units of 1/4000 of the chart area. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'height' => {
      	datatype => 'int',
      	base_name => 'Height',
-     	description => 'Gets or sets the height of frame in units of 1/4000 of the chart area. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'x' => {
      	datatype => 'int',
      	base_name => 'X',
-     	description => 'Gets or sets the x coordinate of the upper left corner in units of 1/4000 of the chart area. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'y' => {
      	datatype => 'int',
      	base_name => 'Y',
-     	description => 'Gets or sets the y coordinate of the upper left corner in units of 1/4000 of the chart area. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
