@@ -35,7 +35,6 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-use AsposeCellsCloud::Object::DataSorterKey;
 use AsposeCellsCloud::Object::SortKey; 
 
 
@@ -119,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Summary description for DataSorter.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'DataSorter',
                                   required => [], # TODO
 }                                 );
@@ -129,42 +128,35 @@ __PACKAGE__->method_documentation({
      'case_sensitive' => {
      	datatype => 'boolean',
      	base_name => 'CaseSensitive',
-     	description => 'Gets and sets whether case sensitive when comparing string. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_headers' => {
      	datatype => 'boolean',
      	base_name => 'HasHeaders',
-     	description => 'Represents whether the range has headers. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'key_list' => {
      	datatype => 'ARRAY[SortKey]',
      	base_name => 'KeyList',
-     	description => 'Gets the key list of data sorter.            ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sort_left_to_right' => {
      	datatype => 'boolean',
      	base_name => 'SortLeftToRight',
-     	description => 'True means that sorting orientation is from left to right.            False means that sorting orientation is from top to bottom.            The default value is false. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'sort_as_number' => {
      	datatype => 'boolean',
      	base_name => 'SortAsNumber',
-     	description => 'Indicates whether sorting anything that looks like a number. ',
-     	format => '',
-     	read_only => '',
-     		},
-     'keys' => {
-     	datatype => 'ARRAY[DataSorterKey]',
-     	base_name => 'Keys',
-     	description => 'Gets the key list of data sorter. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
@@ -175,8 +167,7 @@ __PACKAGE__->swagger_types( {
     'has_headers' => 'boolean',
     'key_list' => 'ARRAY[SortKey]',
     'sort_left_to_right' => 'boolean',
-    'sort_as_number' => 'boolean',
-    'keys' => 'ARRAY[DataSorterKey]' 
+    'sort_as_number' => 'boolean' 
 } );
 
 __PACKAGE__->attribute_map( {
@@ -184,8 +175,7 @@ __PACKAGE__->attribute_map( {
     'has_headers' => 'HasHeaders',
     'key_list' => 'KeyList',
     'sort_left_to_right' => 'SortLeftToRight',
-    'sort_as_number' => 'SortAsNumber',
-    'keys' => 'Keys' 
+    'sort_as_number' => 'SortAsNumber' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
