@@ -128,21 +128,21 @@ __PACKAGE__->method_documentation({
      'dynamic_filter_type' => {
      	datatype => 'string',
      	base_name => 'DynamicFilterType',
-     	description => 'Gets and sets the dynamic filter type. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'max_value' => {
      	datatype => 'string',
      	base_name => 'MaxValue',
-     	description => 'Gets and sets the dynamic filter max value. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'value' => {
      	datatype => 'string',
      	base_name => 'Value',
-     	description => 'Gets and sets the dynamic filter value. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
