@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => '',
+__PACKAGE__->class_documentation({description => 'Describe the IconSet conditional formatting rule. This conditional formatting    rule applies icons to cells according to their values.',
                                   class => 'IconSet',
                                   required => [], # TODO
 }                                 );
@@ -129,42 +129,42 @@ __PACKAGE__->method_documentation({
      'cf_icons' => {
      	datatype => 'ARRAY[ConditionalFormattingIcon]',
      	base_name => 'CfIcons',
-     	description => '',
+     	description => 'Get theAspose.Cells.ConditionalFormattingIcon from the collection',
      	format => '',
      	read_only => '',
      		},
      'cfvos' => {
      	datatype => 'ARRAY[ConditionalFormattingValue]',
      	base_name => 'Cfvos',
-     	description => '',
+     	description => 'Get the CFValueObjects instance.',
      	format => '',
      	read_only => '',
      		},
      'is_custom' => {
      	datatype => 'boolean',
      	base_name => 'IsCustom',
-     	description => '',
+     	description => 'Indicates whether the icon set is custom.  Default value is false.',
      	format => '',
      	read_only => '',
      		},
      'reverse' => {
      	datatype => 'boolean',
      	base_name => 'Reverse',
-     	description => '',
+     	description => 'Get or set the flag indicating whether to reverses the default order of the  icons in this icon set.  Default value is false.            ',
      	format => '',
      	read_only => '',
      		},
      'show_value' => {
      	datatype => 'boolean',
      	base_name => 'ShowValue',
-     	description => '',
+     	description => 'Get or set the flag indicating whether to show the values of the cells on   which this icon set is applied.  Default value is true.            ',
      	format => '',
      	read_only => '',
      		},
      'icon_set_type' => {
      	datatype => 'string',
      	base_name => 'IconSetType',
-     	description => '',
+     	description => 'Get or Set the icon set type to display.  Setting the type will auto check   if the current Cfvos`s count is accord with the new type. If not accord,   old Cfvos will be cleaned and default Cfvos will be added.            ',
      	format => '',
      	read_only => '',
      		},    
