@@ -1,6 +1,6 @@
 =begin comment
 
-Copyright (c) 2022 Aspose.Cells Cloud
+Copyright (c) 2023 Aspose.Cells Cloud
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
@@ -23,7 +23,6 @@ SOFTWARE.
 
 =cut
 
-
 package AsposeCellsCloud::Object::ImportDoubleArrayOption;
 
 require 5.6.0;
@@ -36,9 +35,9 @@ use Module::Runtime qw(use_module);
 use Log::Any qw($log);
 use Date::Parse;
 use DateTime;
-
 use AsposeCellsCloud::Object::FileSource;
-use AsposeCellsCloud::Object::ImportOption;
+use AsposeCellsCloud::Object::ImportOption; 
+
 
 use base ("Class::Accessor", "Class::Data::Inheritable");
 
@@ -54,12 +53,12 @@ sub new {
     my ($class, %args) = @_; 
 
 	my $self = bless {}, $class;
-	
+
 	foreach my $attribute (keys %{$class->attribute_map}) {
 		my $args_key = $class->attribute_map->{$attribute};
 		$self->$attribute( $args{ $args_key } );
 	}
-	
+
 	return $self;
 }  
 
@@ -100,7 +99,7 @@ sub from_hash {
         	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
         }
     }
-  
+
     return $self;
 }
 
@@ -108,7 +107,7 @@ sub from_hash {
 sub _deserialize {
     my ($self, $type, $data) = @_;
     $log->debugf("deserializing %s with %s",Dumper($data), $type);
-        
+
     if ($type eq 'DateTime') {
         return DateTime->from_epoch(epoch => str2time($data));
     } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
@@ -120,94 +119,94 @@ sub _deserialize {
 }
 
 
-
 __PACKAGE__->class_documentation({description => '',
                                   class => 'ImportDoubleArrayOption',
                                   required => [], # TODO
 }                                 );
 
+
 __PACKAGE__->method_documentation({
-    'source' => {
-    	datatype => 'FileSource',
-    	base_name => 'Source',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'import_data_type' => {
-    	datatype => 'string',
-    	base_name => 'ImportDataType',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'destination_worksheet' => {
-    	datatype => 'string',
-    	base_name => 'DestinationWorksheet',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'is_insert' => {
-    	datatype => 'boolean',
-    	base_name => 'IsInsert',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'data' => {
-    	datatype => 'ARRAY[double]',
-    	base_name => 'Data',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'is_vertical' => {
-    	datatype => 'boolean',
-    	base_name => 'IsVertical',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'first_row' => {
-    	datatype => 'int',
-    	base_name => 'FirstRow',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
-    'first_column' => {
-    	datatype => 'int',
-    	base_name => 'FirstColumn',
-    	description => '',
-    	format => '',
-    	read_only => '',
-    		},
+     'first_row' => {
+     	datatype => 'int',
+     	base_name => 'FirstRow',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'first_column' => {
+     	datatype => 'int',
+     	base_name => 'FirstColumn',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'is_vertical' => {
+     	datatype => 'boolean',
+     	base_name => 'IsVertical',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'data' => {
+     	datatype => 'ARRAY[double?]',
+     	base_name => 'Data',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'destination_worksheet' => {
+     	datatype => 'string',
+     	base_name => 'DestinationWorksheet',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'is_insert' => {
+     	datatype => 'boolean',
+     	base_name => 'IsInsert',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'import_data_type' => {
+     	datatype => 'string',
+     	base_name => 'ImportDataType',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},
+     'source' => {
+     	datatype => 'FileSource',
+     	base_name => 'Source',
+     	description => '',
+     	format => '',
+     	read_only => '',
+     		},    
 });
 
 __PACKAGE__->swagger_types( {
-    'source' => 'FileSource',
-    'import_data_type' => 'string',
+    'first_row' => 'int',
+    'first_column' => 'int',
+    'is_vertical' => 'boolean',
+    'data' => 'ARRAY[double?]',
     'destination_worksheet' => 'string',
     'is_insert' => 'boolean',
-    'data' => 'ARRAY[double]',
-    'is_vertical' => 'boolean',
-    'first_row' => 'int',
-    'first_column' => 'int'
+    'import_data_type' => 'string',
+    'source' => 'FileSource' 
 } );
 
 __PACKAGE__->attribute_map( {
-    'source' => 'Source',
-    'import_data_type' => 'ImportDataType',
+    'first_row' => 'FirstRow',
+    'first_column' => 'FirstColumn',
+    'is_vertical' => 'IsVertical',
+    'data' => 'Data',
     'destination_worksheet' => 'DestinationWorksheet',
     'is_insert' => 'IsInsert',
-    'data' => 'Data',
-    'is_vertical' => 'IsVertical',
-    'first_row' => 'FirstRow',
-    'first_column' => 'FirstColumn'
+    'import_data_type' => 'ImportDataType',
+    'source' => 'Source' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
 
 
-1;
+1;
\ No newline at end of file
