@@ -132,77 +132,77 @@ __PACKAGE__->method_documentation({
      'begin_arrowhead_length' => {
      	datatype => 'string',
      	base_name => 'BeginArrowheadLength',
-     	description => 'Gets and sets the begin arrow length type of the line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'begin_arrowhead_style' => {
      	datatype => 'string',
      	base_name => 'BeginArrowheadStyle',
-     	description => 'Gets and sets the begin arrow type of the line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'begin_arrowhead_width' => {
      	datatype => 'string',
      	base_name => 'BeginArrowheadWidth',
-     	description => 'Gets and sets the begin arrow width type of the line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'cap_type' => {
      	datatype => 'string',
      	base_name => 'CapType',
-     	description => 'Specifies the ending caps.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'compound_type' => {
      	datatype => 'string',
      	base_name => 'CompoundType',
-     	description => 'Specifies the line compound type.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'dash_style' => {
      	datatype => 'string',
      	base_name => 'DashStyle',
-     	description => 'Specifies the line dash type.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'end_arrowhead_length' => {
      	datatype => 'string',
      	base_name => 'EndArrowheadLength',
-     	description => 'Gets and sets the end arrow length type of the line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'end_arrowhead_style' => {
      	datatype => 'string',
      	base_name => 'EndArrowheadStyle',
-     	description => 'Gets and sets the end arrow type of the line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'end_arrowhead_width' => {
      	datatype => 'string',
      	base_name => 'EndArrowheadWidth',
-     	description => 'Gets and sets the end arrow width type of the line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'join_type' => {
      	datatype => 'string',
      	base_name => 'JoinType',
-     	description => 'Specifies the line join type.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'weight' => {
      	datatype => 'double',
      	base_name => 'Weight',
-     	description => 'Gets or sets the weight of the line in unit of points.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
