@@ -130,49 +130,49 @@ __PACKAGE__->method_documentation({
      'display_as_icon' => {
      	datatype => 'boolean',
      	base_name => 'DisplayAsIcon',
-     	description => 'True if the specified object is displayed as an icon                         and the image will not be auto changed.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'file_format_type' => {
      	datatype => 'string',
      	base_name => 'FileFormatType',
-     	description => 'Gets and sets the file type of the embedded ole object data',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'image_source_full_name' => {
      	datatype => 'string',
      	base_name => 'ImageSourceFullName',
-     	description => 'Gets or sets the path and name of the source file for the linked image.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_auto_size' => {
      	datatype => 'boolean',
      	base_name => 'IsAutoSize',
-     	description => 'True indicates that the size of the ole object will be auto changed as the size of snapshot of the embedded content                        when the ole object is activated.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_link' => {
      	datatype => 'boolean',
      	base_name => 'IsLink',
-     	description => 'Returns true if the OleObject links to the file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'prog_id' => {
      	datatype => 'string',
      	base_name => 'ProgID',
-     	description => 'Gets or sets the ProgID of the OLE object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'source_full_name' => {
      	datatype => 'string',
      	base_name => 'SourceFullName',
-     	description => 'Returns the source full name of the source file for the linked OLE object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
