@@ -118,7 +118,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Represents the paste special options.            ',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'PasteOptions',
                                   required => [], # TODO
 }                                 );
@@ -128,28 +128,28 @@ __PACKAGE__->method_documentation({
      'only_visible_cells' => {
      	datatype => 'boolean',
      	base_name => 'OnlyVisibleCells',
-     	description => 'True means only copying visible cells. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'paste_type' => {
      	datatype => 'string',
      	base_name => 'PasteType',
-     	description => 'The paste special type. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'skip_blanks' => {
      	datatype => 'boolean',
      	base_name => 'SkipBlanks',
-     	description => 'Indicates whether skips blank cells. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'transpose' => {
      	datatype => 'boolean',
      	base_name => 'Transpose',
-     	description => 'True to transpose rows and columns when the range is pasted. The default value is False. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
