@@ -119,7 +119,7 @@ sub _deserialize {
 }
 
 
-__PACKAGE__->class_documentation({description => 'Indicates range set style request.',
+__PACKAGE__->class_documentation({description => '',
                                   class => 'RangeSetStyleRequest',
                                   required => [], # TODO
 }                                 );
@@ -129,14 +129,14 @@ __PACKAGE__->method_documentation({
      'range' => {
      	datatype => 'Range',
      	base_name => 'Range',
-     	description => 'Encapsulates the object that represents a range of cells within a spreadsheet.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'style' => {
      	datatype => 'Style',
      	base_name => 'Style',
-     	description => 'Represents display style of excel document,such as font,color,alignment,border,etc.            ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
