@@ -132,182 +132,182 @@ __PACKAGE__->method_documentation({
      'area' => {
      	datatype => 'Area',
      	base_name => 'Area',
-     	description => 'Represents the background area of Series object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'bar3_d_shape_type' => {
      	datatype => 'string',
      	base_name => 'Bar3DShapeType',
-     	description => 'Gets or sets the 3D shape type used with the 3-D bar or column chart.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'border' => {
      	datatype => 'Line',
      	base_name => 'Border',
-     	description => 'Represents border of Series object.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'bubble_scale' => {
      	datatype => 'int',
      	base_name => 'BubbleScale',
-     	description => 'Gets or sets the scale factor for bubbles in the specified chart group.                         It can be an integer value from 0 (zero) to 300,                         corresponding to a percentage of the default size.                        Applies only to bubble charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'bubble_sizes' => {
      	datatype => 'string',
      	base_name => 'BubbleSizes',
-     	description => 'Gets or sets the bubble sizes values of the chart series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'count_of_data_values' => {
      	datatype => 'int',
      	base_name => 'CountOfDataValues',
-     	description => 'Gets the number of the data values.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'data_labels' => {
      	datatype => 'LinkElement',
      	base_name => 'DataLabels',
-     	description => 'Represents the DataLabels object for the specified ASeries.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'display_name' => {
      	datatype => 'string',
      	base_name => 'DisplayName',
-     	description => 'Gets the series`s name that displays on the chart graph.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'doughnut_hole_size' => {
      	datatype => 'int',
      	base_name => 'DoughnutHoleSize',
-     	description => 'Returns or sets the size of the hole in a doughnut chart group.                         The hole size is expressed as a percentage of the chart size, between 10 and 90 percent.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'down_bars' => {
      	datatype => 'LinkElement',
      	base_name => 'DownBars',
-     	description => 'Returns a  object that represents the down bars on a line chart.                        Applies only to line charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'drop_lines' => {
      	datatype => 'Line',
      	base_name => 'DropLines',
-     	description => 'Returns a  object that represents the drop lines for a series on the line chart or area chart.                        Applies only to line chart or area charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'explosion' => {
      	datatype => 'int',
      	base_name => 'Explosion',
-     	description => 'The distance of an open pie slice from the center of the pie chart is expressed as a percentage of the pie diameter.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'first_slice_angle' => {
      	datatype => 'int',
      	base_name => 'FirstSliceAngle',
-     	description => 'Gets or sets the angle of the first pie-chart or doughnut-chart slice, in degrees (clockwise from vertical).                         Applies only to pie, 3-D pie, and doughnut charts, 0 to 360.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'gap_width' => {
      	datatype => 'int',
      	base_name => 'GapWidth',
-     	description => 'Returns or sets the space between bar or column clusters, as a percentage of the bar or column width.                        The value of this property must be between 0 and 500.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has3_d_effect' => {
      	datatype => 'boolean',
      	base_name => 'Has3DEffect',
-     	description => 'True if the series has a three-dimensional appearance.                         Applies only to bubble charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_drop_lines' => {
      	datatype => 'boolean',
      	base_name => 'HasDropLines',
-     	description => 'True if the chart has drop lines.                        Applies only to line chart or area charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_hi_lo_lines' => {
      	datatype => 'boolean',
      	base_name => 'HasHiLoLines',
-     	description => 'True if the line chart has high-low lines.                          Applies only to line charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_leader_lines' => {
      	datatype => 'boolean',
      	base_name => 'HasLeaderLines',
-     	description => 'True if the series has leader lines.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_radar_axis_labels' => {
      	datatype => 'boolean',
      	base_name => 'HasRadarAxisLabels',
-     	description => 'True if a radar chart has category axis labels. Applies only to radar charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_series_lines' => {
      	datatype => 'boolean',
      	base_name => 'HasSeriesLines',
-     	description => 'True if a stacked column chart or bar chart has series lines or                        if a Pie of Pie chart or Bar of Pie chart has connector lines between the two sections.                         Applies only to stacked column charts, bar charts, Pie of Pie charts, or Bar of Pie charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'has_up_down_bars' => {
      	datatype => 'boolean',
      	base_name => 'HasUpDownBars',
-     	description => 'True if a line chart has up and down bars.                        Applies only to line charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'hi_lo_lines' => {
      	datatype => 'Line',
      	base_name => 'HiLoLines',
-     	description => 'Returns a HiLoLines object that represents the high-low lines for a series on a line chart.                         Applies only to line charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_auto_split' => {
      	datatype => 'boolean',
      	base_name => 'IsAutoSplit',
-     	description => 'Indicates whether the threshold value is automatic.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'is_color_varied' => {
      	datatype => 'boolean',
      	base_name => 'IsColorVaried',
-     	description => 'Represents if the color of points is varied.                         The chart must contain only one series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'leader_lines' => {
      	datatype => 'Line',
      	base_name => 'LeaderLines',
-     	description => 'Represents leader lines on a chart. Leader lines connect data labels to data points.                         This object isn’t a collection; there’s no object that represents a single leader line.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'legend_entry' => {
      	datatype => 'LinkElement',
      	base_name => 'LegendEntry',
-     	description => 'Gets the legend entry according to this series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
@@ -321,147 +321,147 @@ __PACKAGE__->method_documentation({
      'marker' => {
      	datatype => 'Marker',
      	base_name => 'Marker',
-     	description => 'Gets the marker.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'name' => {
      	datatype => 'string',
      	base_name => 'Name',
-     	description => 'Gets or sets the name of the data series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'overlap' => {
      	datatype => 'int',
      	base_name => 'Overlap',
-     	description => 'Specifies how bars and columns are positioned.                        Can be a value between – 100 and 100.                         Applies only to 2-D bar and 2-D column charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'plot_on_second_axis' => {
      	datatype => 'boolean',
      	base_name => 'PlotOnSecondAxis',
-     	description => 'Indicates if this series is plotted on second value axis.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'points' => {
      	datatype => 'LinkElement',
      	base_name => 'Points',
-     	description => 'Gets the collection of points in a series in a chart.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'second_plot_size' => {
      	datatype => 'int',
      	base_name => 'SecondPlotSize',
-     	description => 'Returns or sets the size of the secondary section of either a pie of pie chart or a bar of pie chart,                         as a percentage of the size of the primary pie.                        Can be a value from 5 to 200.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'series_lines' => {
      	datatype => 'Line',
      	base_name => 'SeriesLines',
-     	description => 'Returns a SeriesLines object that represents the series lines for a stacked bar chart or a stacked column chart.                        Applies only to stacked bar and stacked column charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'shadow' => {
      	datatype => 'boolean',
      	base_name => 'Shadow',
-     	description => 'True if the series has a shadow.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'shape_properties' => {
      	datatype => 'LinkElement',
      	base_name => 'ShapeProperties',
-     	description => 'Gets the  object that holds the visual shape properties of the Series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'show_negative_bubbles' => {
      	datatype => 'boolean',
      	base_name => 'ShowNegativeBubbles',
-     	description => 'True if negative bubbles are shown for the chart group. Valid only for bubble charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'size_represents' => {
      	datatype => 'string',
      	base_name => 'SizeRepresents',
-     	description => 'Gets or sets what the bubble size represents on a bubble chart.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'smooth' => {
      	datatype => 'boolean',
      	base_name => 'Smooth',
-     	description => 'Represents curve smoothing.                         True if curve smoothing is turned on for the line chart or scatter chart.                        Applies only to line and scatter connected by lines charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'split_type' => {
      	datatype => 'string',
      	base_name => 'SplitType',
-     	description => 'Returns or sets a value that how to determine which data points are in the second pie or bar on a pie of pie or bar of                        pie chart.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'split_value' => {
      	datatype => 'double',
      	base_name => 'SplitValue',
-     	description => 'Returns or sets a value that shall be used to determine which data points are in the second pie or bar on                        a pie of pie or bar of pie chart.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'trend_lines' => {
      	datatype => 'LinkElement',
      	base_name => 'TrendLines',
-     	description => 'Returns an object that represents a collection of all the trendlines for the series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'type' => {
      	datatype => 'string',
      	base_name => 'Type',
-     	description => 'Gets or sets a data series` type.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'up_bars' => {
      	datatype => 'LinkElement',
      	base_name => 'UpBars',
-     	description => 'Returns an DropBars object that represents the up bars on a line chart.                        Applies only to line charts.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'values' => {
      	datatype => 'string',
      	base_name => 'Values',
-     	description => 'Represents the data of the chart series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'x_error_bar' => {
      	datatype => 'LinkElement',
      	base_name => 'XErrorBar',
-     	description => 'Represents X direction error bar of the series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'x_values' => {
      	datatype => 'string',
      	base_name => 'XValues',
-     	description => 'Represents the x values of the chart series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'y_error_bar' => {
      	datatype => 'LinkElement',
      	base_name => 'YErrorBar',
-     	description => 'Represents Y direction error bar of the series.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
