@@ -128,49 +128,49 @@ __PACKAGE__->method_documentation({
      'angle' => {
      	datatype => 'double',
      	base_name => 'Angle',
-     	description => 'Gets and sets the lighting angle. Range from 0 to 359.9 degrees. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'blur' => {
      	datatype => 'double',
      	base_name => 'Blur',
-     	description => 'Gets and sets the blur of the shadow. Range from 0 to 100 points. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'color' => {
      	datatype => 'CellsColor',
      	base_name => 'Color',
-     	description => 'Gets and sets the color of the shadow. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'distance' => {
      	datatype => 'double',
      	base_name => 'Distance',
-     	description => 'Gets and sets the distance of the shadow. Range from 0 to 200 points. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'preset_type' => {
      	datatype => 'string',
      	base_name => 'PresetType',
-     	description => 'Gets and sets the preset shadow type of the shadow. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'size' => {
      	datatype => 'double',
      	base_name => 'Size',
-     	description => 'Gets and sets the size of the shadow. Range from 0 to 2.0.             Meaningless in inner shadow. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'transparency' => {
      	datatype => 'double',
      	base_name => 'Transparency',
-     	description => 'Gets and sets the degree of transparency of the shadow. Range from 0.0 (opaque) to 1.0 (clear). ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
