@@ -129,21 +129,21 @@ __PACKAGE__->method_documentation({
      'color' => {
      	datatype => 'Color',
      	base_name => 'Color',
-     	description => 'Gets or sets the . ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'cells_color' => {
      	datatype => 'CellsColor',
      	base_name => 'CellsColor',
-     	description => 'Gets and sets the  object. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'transparency' => {
      	datatype => 'double',
      	base_name => 'Transparency',
-     	description => 'Returns or sets the degree of transparency of the area as a value from 0.0 (opaque) through 1.0 (clear). ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
