@@ -128,14 +128,14 @@ __PACKAGE__->method_documentation({
      'color_type' => {
      	datatype => 'string',
      	base_name => 'ColorType',
-     	description => 'Gets and sets the theme type. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'tint' => {
      	datatype => 'double',
      	base_name => 'Tint',
-     	description => 'Gets and sets the tint value. ',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
