@@ -59,10 +59,10 @@ sub new {
 
 
 # Run Operation Request
-# DeleteWorksheetHyperlinksRequest.name :   ,
-# DeleteWorksheetHyperlinksRequest.sheetName :   ,
-# DeleteWorksheetHyperlinksRequest.folder :   ,
-# DeleteWorksheetHyperlinksRequest.storageName :    
+# DeleteWorksheetHyperlinksRequest.name : The workbook name.  ,
+# DeleteWorksheetHyperlinksRequest.sheetName : The worksheet name.  ,
+# DeleteWorksheetHyperlinksRequest.folder : Original workbook folder.  ,
+# DeleteWorksheetHyperlinksRequest.storageName : Storage name.   
 
 {
     my $params = {
@@ -73,7 +73,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'delete_worksheet_hyperlinks' } = { 
-    	summary => '',
+    	summary => 'Delete all hyperlinks in worksheet.',
         params => $params,
         returns => 'CellsCloudResponse',
     };
@@ -130,28 +130,28 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The workbook name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'Original workbook folder.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'Storage name.',
      	format => '',
      	read_only => '',
      		},    
