@@ -59,11 +59,11 @@ sub new {
 
 
 # Run Operation Request
-# GetWorksheetColumnRequest.name :   ,
-# GetWorksheetColumnRequest.sheetName :   ,
-# GetWorksheetColumnRequest.columnIndex :   ,
-# GetWorksheetColumnRequest.folder :   ,
-# GetWorksheetColumnRequest.storageName :    
+# GetWorksheetColumnRequest.name : The workbook name.  ,
+# GetWorksheetColumnRequest.sheetName : The worksheet name.  ,
+# GetWorksheetColumnRequest.columnIndex : The column index.  ,
+# GetWorksheetColumnRequest.folder : Original workbook folder.  ,
+# GetWorksheetColumnRequest.storageName : Storage name.   
 
 {
     my $params = {
@@ -74,7 +74,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'get_worksheet_column' } = { 
-    	summary => '',
+    	summary => 'Gets worksheet column data by column`s index.',
         params => $params,
         returns => 'ColumnResponse',
     };
@@ -137,35 +137,35 @@ __PACKAGE__->method_documentation({
      'name' => {
      	datatype => 'string',
      	base_name => 'name',
-     	description => '',
+     	description => 'The workbook name.',
      	format => '',
      	read_only => '',
      		},
      'sheet_name' => {
      	datatype => 'string',
      	base_name => 'sheetName',
-     	description => '',
+     	description => 'The worksheet name.',
      	format => '',
      	read_only => '',
      		},
      'column_index' => {
      	datatype => 'int',
      	base_name => 'columnIndex',
-     	description => '',
+     	description => 'The column index.',
      	format => '',
      	read_only => '',
      		},
      'folder' => {
      	datatype => 'string',
      	base_name => 'folder',
-     	description => '',
+     	description => 'Original workbook folder.',
      	format => '',
      	read_only => '',
      		},
      'storage_name' => {
      	datatype => 'string',
      	base_name => 'storageName',
-     	description => '',
+     	description => 'Storage name.',
      	format => '',
      	read_only => '',
      		},    
