@@ -59,10 +59,9 @@ sub new {
 
 
 # Run Operation Request
-# PostConvertWorkbookToDocxRequest.File : The password needed to open an Excel file.  ,
-# PostConvertWorkbookToDocxRequest.password : The password needed to open an Excel file.  ,
-# PostConvertWorkbookToDocxRequest.checkExcelRestriction : Whether check restriction of excel file when user modify cells related objects.  ,
-# PostConvertWorkbookToDocxRequest.region : The regional settings for workbook.   
+# PostConvertWorkbookToDocxRequest.File : File to upload  ,
+# PostConvertWorkbookToDocxRequest.password :   ,
+# PostConvertWorkbookToDocxRequest.checkExcelRestriction :    
 
 {
     my $params = {
@@ -73,7 +72,7 @@ sub new {
        }
     };
     __PACKAGE__->method_documentation->{ 'post_convert_workbook_to_docx' } = { 
-    	summary => 'Convert Excel file to Docx files.',
+    	summary => '',
         params => $params,
         returns => 'FileInfo',
     };
@@ -105,10 +104,6 @@ sub run_http_request {
 
     if(defined $self->check_excel_restriction){
         $query_params->{'checkExcelRestriction'} = $client->to_query_value($self->check_excel_restriction);      
-    }
-
-    if(defined $self->region){
-        $query_params->{'region'} = $client->to_query_value($self->region);      
     } 
     my $_body_data;
  
@@ -133,28 +128,21 @@ __PACKAGE__->method_documentation({
      'file' => {
      	datatype => 'string',
      	base_name => 'File',
-     	description => 'The password needed to open an Excel file.',
+     	description => 'File to upload',
      	format => '',
      	read_only => '',
      		},
      'password' => {
      	datatype => 'string',
      	base_name => 'password',
-     	description => 'The password needed to open an Excel file.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},
      'check_excel_restriction' => {
      	datatype => 'string',
      	base_name => 'checkExcelRestriction',
-     	description => 'Whether check restriction of excel file when user modify cells related objects.',
-     	format => '',
-     	read_only => '',
-     		},
-     'region' => {
-     	datatype => 'string',
-     	base_name => 'region',
-     	description => 'The regional settings for workbook.',
+     	description => '',
      	format => '',
      	read_only => '',
      		},    
@@ -164,8 +152,7 @@ __PACKAGE__->method_documentation({
 __PACKAGE__->attribute_map( {
     'file' => 'File',
     'password' => 'password',
-    'check_excel_restriction' => 'checkExcelRestriction',
-    'region' => 'region' 
+    'check_excel_restriction' => 'checkExcelRestriction' 
 } );
 
 __PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});
